==> codelite_6.1.1+dfsg.orig.tar.gz: codelite-6.1.1/MacBundler/macbundler.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 The CodeLite Team
// file name            : macbundler.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __MacBundler__
#define __MacBundler__

#include "plugin.h"
#include "workspace.h"

class wxCommandEvent;

class MacBundler : public IPlugin
{
    int m_popup_id;
    void showSettingsDialogFor(ProjectPtr project);

public:
	MacBundler(IManager *manager);
	~MacBundler();

    void onBundleInvoked_active(wxCommandEvent& evt);
    void onBundleInvoked_selected(wxCommandEvent& evt);

	//--------------------------------------------
	//Abstract methods
	//--------------------------------------------
	virtual clToolBar *CreateToolBar(wxWindow *parent);
	virtual void CreatePluginMenu(wxMenu *pluginsMenu);
	virtual void HookPopupMenu(wxMenu *menu, MenuType type);
	virtual void UnPlug();
};

#endif //MacBundler

==> codelite_18.2.0.orig.tar.gz: codelite-18.2.0/MacBundler/macbundler.h <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2014 Eran Ifrah
// file name            : macbundler.h
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#ifndef __MacBundler__
#define __MacBundler__

#include "plugin.h"
#include "workspace.h"

class wxCommandEvent;

class MacBundler : public IPlugin
{
    void showSettingsDialogFor(ProjectPtr project);

public:
    MacBundler(IManager* manager);
    ~MacBundler() override = default;

    void onBundleInvoked_active(wxCommandEvent& evt);
    void onBundleInvoked_selected(wxCommandEvent& evt);

    //--------------------------------------------
    // Abstract methods
    //--------------------------------------------
    void CreateToolBar(clToolBarGeneric* toolbar) override;
    void CreatePluginMenu(wxMenu* pluginsMenu) override;
    void HookPopupMenu(wxMenu* menu, MenuType type) override;
    void UnPlug() override;
};

#endif // MacBundler
